<p align="center">
  <a href="https://docs.engagesmarter.ai/"><img width="350" height="208" src="https://raw.githubusercontent.com/engagesmarter/engagesmarter-py/master/docs/img/es_logo.jpg" alt='Engage Smarter AI'></a>
</p>

<h1 align="center"><strong>Engage Smarter AI Platform Python Client</strong></h1>

<p align="center">
<!-- <a href="https://github.com/engagesmarter/engagesmarter-py/actions">
    <img src="https://github.com/engagesmarter/engagesmarter-py/workflows/Test%20Suite/badge.svg" alt="Test Suite">
</a> -->
<a href="https://pypi.org/project/engagesmarter-py/">
    <img src="https://badge.fury.io/py/engagesmarter-py.svg" alt="Package version">
</a>
</p>

The Engage Smarter AI Platform Python Client provides a simple way to interact with the Engage Smarter AI Platform from Python.

For more information on how to interact with the Engage Smarter AI Platform API, please visit the Engage Smarter AI Platform [developer docs](https://docs.engagesmarter.ai/).
